@@ -78,12 +78,13 @@ clean_names.character <- function(x, include_names = FALSE, ...) {
     # treated as "interaction"
     .x <- sub("\\[(\\d+):(\\d+)\\]", "", .x)
     if (grepl(":", .x, fixed = TRUE) && !grepl("::", .x, fixed = TRUE)) {
-      paste(sapply(
-        strsplit(.x, ":", fixed = TRUE),
-        .remove_pattern_from_names,
-        is_emmeans = is_emmeans
-      ),
-      collapse = ":"
+      paste(
+        sapply(
+          strsplit(.x, ":", fixed = TRUE),
+          .remove_pattern_from_names,
+          is_emmeans = is_emmeans
+        ),
+        collapse = ":"
       )
     } else {
       .remove_pattern_from_names(.x, is_emmeans = is_emmeans)
@@ -160,7 +161,7 @@ clean_names.character <- function(x, include_names = FALSE, ...) {
         } else if (pattern[j] == "scale(poly") {
           x[i] <- trim_ws(unique(sub("^scale\\(poly\\(((\\w|\\.)*).*", "\\1", x[i])))
         } else if (pattern[j] %in% c("mmc", "mm")) {
-          ## TODO multimembership-models need to be fixed
+          ## FIXME multimembership-models need to be fixed
           p <- paste0("^", pattern[j], "\\((.*)\\).*")
           g <- trim_ws(sub(p, "\\1", x[i]))
           x[i] <- trim_ws(unlist(strsplit(g, ",")))
