@@ -188,9 +188,11 @@ find_parameters.bfsl <- function(x, flatten = FALSE, ...) {
 #' @export
 find_parameters.marginaleffects <- function(x, flatten = FALSE, ...) {
   # Recover dataframe
-  excl <- c("rowid", "type", "std.error", "contrast", "term", "dydx",
-            "statistic", "p.value", "conf.low", "conf.high", "predicted_hi",
-            "predicted_lo", "eps", "marginaleffects_eps")
+  excl <- c(
+    "rowid", "type", "std.error", "contrast", "term", "dydx",
+    "statistic", "p.value", "conf.low", "conf.high", "predicted_hi",
+    "predicted_lo", "eps", "marginaleffects_eps"
+  )
 
   params <- x[!names(x) %in% excl]
 
