@@ -95,6 +95,7 @@ find_terms.aovlist <- function(x, flatten = FALSE, verbose = TRUE, ...) {
   }
 }
 
+
 #' @export
 find_terms.afex_aov <- function(x, flatten = FALSE, verbose = TRUE, ...) {
   resp <- find_response(x, verbose = FALSE)
@@ -115,7 +116,6 @@ find_terms.afex_aov <- function(x, flatten = FALSE, verbose = TRUE, ...) {
 }
 
 
-
 #' @export
 find_terms.bfsl <- function(x, flatten = FALSE, verbose = TRUE, ...) {
   resp <- find_response(x, verbose = FALSE)
@@ -136,8 +136,14 @@ find_terms.bfsl <- function(x, flatten = FALSE, verbose = TRUE, ...) {
 }
 
 
+# unsupported ------------------
 
 
+#' @export
+find_terms.mipo <- function(x, ...) {
+  NULL
+}
+
 
 
 # helper -----------------------
