@@ -60,18 +60,58 @@ format_value <- function(x, ...) {
 
 #' @rdname format_value
 #' @export
-format_value.data.frame <- function(x, digits = 2, protect_integers = FALSE, missing = "", width = NULL, as_percent = FALSE, zap_small = FALSE, ...) {
-  as.data.frame(sapply(x, format_value, digits = digits, protect_integers = protect_integers, missing = missing, width = width, as_percent = as_percent, zap_small = zap_small, simplify = FALSE))
+format_value.data.frame <- function(x,
+                                    digits = 2,
+                                    protect_integers = FALSE,
+                                    missing = "",
+                                    width = NULL,
+                                    as_percent = FALSE,
+                                    zap_small = FALSE,
+                                    ...) {
+  as.data.frame(sapply(
+    x,
+    format_value,
+    digits = digits,
+    protect_integers = protect_integers,
+    missing = missing,
+    width = width,
+    as_percent = as_percent,
+    zap_small = zap_small,
+    simplify = FALSE
+  ))
 }
 
 
 #' @rdname format_value
 #' @export
-format_value.numeric <- function(x, digits = 2, protect_integers = FALSE, missing = "", width = NULL, as_percent = FALSE, zap_small = FALSE, ...) {
+format_value.numeric <- function(x,
+                                 digits = 2,
+                                 protect_integers = FALSE,
+                                 missing = "",
+                                 width = NULL,
+                                 as_percent = FALSE,
+                                 zap_small = FALSE,
+                                 ...) {
   if (protect_integers) {
-    out <- .format_value_unless_integer(x, digits = digits, .missing = missing, .width = width, .as_percent = as_percent, .zap_small = zap_small, ...)
+    out <- .format_value_unless_integer(
+      x,
+      digits = digits,
+      .missing = missing,
+      .width = width,
+      .as_percent = as_percent,
+      .zap_small = zap_small,
+      ...
+    )
   } else {
-    out <- .format_value(x, digits = digits, .missing = missing, .width = width, .as_percent = as_percent, .zap_small = zap_small, ...)
+    out <- .format_value(
+      x,
+      digits = digits,
+      .missing = missing,
+      .width = width,
+      .as_percent = as_percent,
+      .zap_small = zap_small,
+      ...
+    )
   }
 
   # Deal with negative zeros
@@ -111,9 +151,21 @@ format_percent <- function(x, ...) {
 
 
 
-.format_value_unless_integer <- function(x, digits = 2, .missing = "", .width = NULL, .as_percent = FALSE, .zap_small = FALSE, ...) {
+.format_value_unless_integer <- function(x,
+                                         digits = 2,
+                                         .missing = "",
+                                         .width = NULL,
+                                         .as_percent = FALSE,
+                                         .zap_small = FALSE, ...) {
   if (is.numeric(x) && !all(.is.int(stats::na.omit(x)))) {
-    .format_value(x, digits = digits, .missing = .missing, .width = .width, .as_percent = .as_percent, .zap_small = .zap_small)
+    .format_value(
+      x,
+      digits = digits,
+      .missing = .missing,
+      .width = .width,
+      .as_percent = .as_percent,
+      .zap_small = .zap_small
+    )
   } else if (anyNA(x)) {
     .convert_missing(x, .missing)
   } else if (is.numeric(x) && all(.is.int(stats::na.omit(x))) && !is.null(.width)) {
@@ -209,7 +261,6 @@ format_percent <- function(x, ...) {
 }
 
 
-
 .is.int <- function(x) {
   tryCatch(
     expr = {
