@@ -1,6 +1,4 @@
-if (require("testthat") &&
-  require("insight") &&
-  require("blme")) {
+if (requiet("testthat") && requiet("insight") && requiet("blme")) {
   data(sleepstudy)
   set.seed(123)
   sleepstudy$mygrp <- sample(1:5, size = 180, replace = TRUE)
@@ -16,11 +14,11 @@ if (require("testthat") &&
     cov.prior = NULL
   )
 
-  m2 <- blmer(
+  m2 <- suppressWarnings(blmer(
     Reaction ~ Days + (1 | mygrp / mysubgrp) + (1 | Subject),
     data = sleepstudy,
     cov.prior = wishart
-  )
+  ))
 
   test_that("model_info", {
     expect_true(model_info(m1)$is_linear)
@@ -28,6 +26,10 @@ if (require("testthat") &&
     expect_true(model_info(m1)$is_bayesian)
   })
 
+  test_that("get_varcov", {
+    expect_equal(as.matrix(vcov(m1)), get_varcov(m1), tolerance = 1e-3)
+  })
+
   test_that("find_predictors", {
     expect_equal(
       find_predictors(m1, effects = "all"),
@@ -126,7 +128,8 @@ if (require("testthat") &&
       list(
         conditional = as.formula("Reaction ~ Days"),
         random = as.formula("~1 + Days | Subject")
-      )
+      ),
+      ignore_attr = TRUE
     )
     expect_equal(
       find_formula(m2, component = "conditional"),
@@ -137,7 +140,8 @@ if (require("testthat") &&
           as.formula("~1 | mygrp"),
           as.formula("~1 | Subject")
         )
-      )
+      ),
+      ignore_attr = TRUE
     )
   })
 
